/* Reset */
.thebigreasonSkin table, .thebigreasonSkin tbody, .thebigreasonSkin a, .thebigreasonSkin img, .thebigreasonSkin tr, .thebigreasonSkin div, .thebigreasonSkin td, .thebigreasonSkin iframe, .thebigreasonSkin span, .thebigreasonSkin *, .thebigreasonSkin .mceText {border:0; margin:0; padding:0; background:transparent; white-space:nowrap; text-decoration:none; font-weight:normal; cursor:thebigreason; color:#000; vertical-align:baseline; width:auto; border-collapse:separate; text-align:left}
.thebigreasonSkin a:hover, .thebigreasonSkin a:link, .thebigreasonSkin a:visited, .thebigreasonSkin a:active {text-decoration:none; font-weight:normal; cursor:thebigreason; color:#000}
.thebigreasonSkin table td {vertical-align:middle}
*:focus{outline:0;}

/* Containers */
/*.thebigreasonSkin table {background:#F0F0EE}*/
.thebigreasonSkin iframe {display:block; background:#FFF}
.thebigreasonSkin .mceToolbar {height:26px}
.thebigreasonSkin .mceLeft {text-align:left}
.thebigreasonSkin .mceRight {text-align:right}

/* External */
.thebigreasonSkin .mceExternalToolbar {position:absolute; border:1px solid #CCC; border-bottom:0; display:none;}
.thebigreasonSkin .mceExternalToolbar td.mceToolbar {padding-right:13px;}
.thebigreasonSkin .mceExternalClose {position:absolute; top:3px; right:3px; width:7px; height:7px; background:url('img/icons.png') -820px 0}

/* Layout */
.thebigreasonSkin table.mceLayout {border:0; border-left:1px solid #CCC; border-right:1px solid #CCC}
.thebigreasonSkin table.mceLayout tr.mceFirst td {border-top:1px solid #CCC}
.thebigreasonSkin table.mceLayout tr.mceLast td {border-bottom:1px solid #CCC;background:url('img/toolbar-bg.png') center repeat-x;}
.thebigreasonSkin table.mceToolbar, .thebigreasonSkin tr.mceFirst .mceToolbar tr td, .thebigreasonSkin tr.mceLast .mceToolbar tr td {border:0; margin:0; padding:0;}
.thebigreasonSkin td.mceToolbar {padding-top: 1px; vertical-align: top;background: #efefef url('img/toolbar-bg.png') bottom repeat-x;}
.thebigreasonSkin .mceIframeContainer {border-top:1px solid #CCC; border-bottom:1px solid #CCC}
.thebigreasonSkin .mceStatusbar {font:11px'Lucida Grande',Helvetica,Arial,sans-serif; overflow:visible; color:#666; display:block; height:20px}
.thebigreasonSkin .mceStatusbar div {float:left; margin:3px 0 0 4px; color:#666;}
.thebigreasonSkin .mceStatusbar a.mceResize {display:block; float:right; background:url('img/icons.png') -801px -2px; width:20px; height:20px; cursor:se-resize}
.thebigreasonSkin .mceStatusbar a:hover {text-decoration:underline}
.thebigreasonSkin table.mceToolbar {margin-left:3px}
.thebigreasonSkin span.mceIcon, .thebigreasonSkin img.mceIcon {display:block; width:20px; height:20px}
.thebigreasonSkin .mceIcon {background:url('img/icons.png') no-repeat 20px 20px}
.thebigreasonSkin td.mceCenter {text-align:center;}
.thebigreasonSkin td.mceCenter table {margin:0 auto; text-align:left;}
.thebigreasonSkin td.mceRight table {margin:0 0 0 auto;}

/* Button */
.thebigreasonSkin .mceButton {display:block; border:1px solid transparent; width:20px; height:20px; margin-right:1px}
.thebigreasonSkin a.mceButtonEnabled:hover {border:1px solid #ccc; background-color:#F1F1F1}
.thebigreasonSkin a.mceButtonActive, .thebigreasonSkin a.mceButtonSelected {border:1px solid #ccc; background-color:#F1F1F1}
.thebigreasonSkin .mceButtonDisabled .mceIcon {opacity:0.3; filter:alpha(opacity=30)}
.thebigreasonSkin .mceButtonLabeled {width:auto}
.thebigreasonSkin .mceButtonLabeled span.mceIcon {float:left}
.thebigreasonSkin span.mceButtonLabel {display:block; font-size:10px; padding:4px 6px 0 22px; font-family:Tahoma,Verdana,Arial,Helvetica}
.thebigreasonSkin .mceButtonDisabled .mceButtonLabel {color:#888}

/* Separator */
.thebigreasonSkin .mceSeparator {display:block; background:url('img/icons.png') -180px 0; width:2px; height:20px; margin:2px 2px 0 4px}

/* ListBox */
.thebigreasonSkin .mceListBox {direction:ltr}
.thebigreasonSkin .mceListBox, .thebigreasonSkin .mceListBox a {display:block}
.thebigreasonSkin .mceListBox .mceText {padding-left:4px; width:70px; text-align:left; border:1px solid #CCC; border-right:0; background:#FFF; font:11px 'Lucida Grande',Helvetica,Arial,sans-serif; height:20px; line-height:20px; overflow:hidden}
.thebigreasonSkin .mceListBox .mceOpen {width:9px; height:20px; background:url('img/icons.png') -741px 0; margin-right:2px; border:1px solid #CCC;}
.thebigreasonSkin table.mceListBoxEnabled:hover .mceText, .thebigreasonSkin .mceListBoxHover .mceText, .thebigreasonSkin .mceListBoxSelected .mceText {border:1px solid #aaa; border-right:0; background:#FFF}
.thebigreasonSkin table.mceListBoxEnabled:hover .mceOpen, .thebigreasonSkin .mceListBoxHover .mceOpen, .thebigreasonSkin .mceListBoxSelected .mceOpen {background-color:#FFF; border:1px solid #aaa}
.thebigreasonSkin .mceListBoxDisabled a.mceText {color:gray; background-color:transparent;}
.thebigreasonSkin .mceListBoxMenu {box-shadow: rgba(0,0,0,0.2) 0 5px 5px;overflow:auto;overflow-x:hidden;}

.thebigreasonSkin .mceListBoxMenu:focus {
	outline:none;
}

.thebigreasonSkin .mceOldBoxModel .mceListBox .mceText {height:22px}
.thebigreasonSkin .mceOldBoxModel .mceListBox .mceOpen {width:11px; height:22px;}
.thebigreasonSkin select.mceNativeListBox {font:11px'Lucida Grande',Helvetica,Arial,sans-serif; background:#F0F0EE; border:1px solid gray; margin-right:2px;}

/* SplitButton */
.thebigreasonSkin .mceSplitButton {width:32px; height:20px; direction:ltr}
.thebigreasonSkin .mceSplitButton a, .thebigreasonSkin .mceSplitButton span {height:20px; display:block}
.thebigreasonSkin .mceSplitButton a.mceAction {width:20px; border:1px solid #F0F0EE; border-right:0;}
.thebigreasonSkin .mceSplitButton span.mceAction {width:20px; background:url('img/icons.png') 20px 20px;}
.thebigreasonSkin .mceSplitButton a.mceOpen {width:9px; border:1px solid #F0F0EE;}
.thebigreasonSkin .mceSplitButton span.mceOpen {width:9px; background:url('img/icons.png') -741px 0;}
.thebigreasonSkin table.mceSplitButtonEnabled:hover a.mceAction, .thebigreasonSkin .mceSplitButtonHover a.mceAction, .thebigreasonSkin .mceSplitButtonSelected a.mceAction {border:1px solid #0A246A; border-right:0; background-color:#B2BBD0}
.thebigreasonSkin table.mceSplitButtonEnabled:hover a.mceOpen, .thebigreasonSkin .mceSplitButtonHover a.mceOpen, .thebigreasonSkin .mceSplitButtonSelected a.mceOpen {border:1px solid #0A246A;}
.thebigreasonSkin table.mceSplitButtonEnabled:hover span.mceOpen, .thebigreasonSkin .mceSplitButtonHover span.mceOpen, .thebigreasonSkin .mceSplitButtonSelected span.mceOpen {background-color:#B2BBD0}
.thebigreasonSkin .mceSplitButtonDisabled .mceAction, .thebigreasonSkin .mceSplitButtonDisabled span.mceOpen {opacity:0.3; filter:alpha(opacity=30)}
.thebigreasonSkin .mceSplitButtonActive a.mceAction {border:1px solid #0A246A; background-color:#C2CBE0}
.thebigreasonSkin .mceSplitButtonActive a.mceOpen {border-left:0;}

/* ColorSplitButton */
.thebigreasonSkin div.mceColorSplitMenu table {background:#FFF; border:1px solid gray}
.thebigreasonSkin .mceColorSplitMenu td {padding:2px}
.thebigreasonSkin .mceColorSplitMenu a {display:block; width:9px; height:9px; overflow:hidden; border:1px solid #808080}
.thebigreasonSkin .mceColorSplitMenu td.mceMoreColors {padding:1px 3px 1px 1px}
.thebigreasonSkin .mceColorSplitMenu a.mceMoreColors {width:100%; height:auto; text-align:center; font-family:Tahoma,Verdana,Arial,Helvetica; font-size:11px; line-height:20px; border:1px solid #FFF}
.thebigreasonSkin .mceColorSplitMenu a.mceMoreColors:hover {border:1px solid #0A246A; background-color:#B6BDD2}
.thebigreasonSkin a.mceMoreColors:hover {border:1px solid #0A246A}
.thebigreasonSkin .mceColorPreview {margin-left:2px; width:16px; height:4px; overflow:hidden; background:#9a9b9a}
.thebigreasonSkin .mce_forecolor span.mceAction, .thebigreasonSkin .mce_backcolor span.mceAction {overflow:hidden; height:16px}

/* Menu */
.thebigreasonSkin .mceMenu {position:absolute; left:0; top:0; z-index:1000; border:1px solid #D4D0C8}
.thebigreasonSkin .mceNoIcons span.mceIcon {width:0;}
.thebigreasonSkin .mceNoIcons a .mceText {padding-left:10px}
.thebigreasonSkin .mceMenu table {background:#FFF}
.thebigreasonSkin .mceMenu a, .thebigreasonSkin .mceMenu span, .thebigreasonSkin .mceMenu {display:block}
.thebigreasonSkin .mceMenu td {height:20px}
.thebigreasonSkin .mceMenu a {position:relative;padding:3px 0 4px 0}
.thebigreasonSkin .mceMenu .mceText {position:relative; display:block; font-family:'Lucida Grande',Helvetica,Arial,sans-serif; color:#000; cursor:thebigreason; margin:0; padding:0 25px 0 25px; display:block}
.thebigreasonSkin .mceMenu span.mceText, .thebigreasonSkin .mceMenu .mcePreview {font-size:11px}
.thebigreasonSkin .mceMenu pre.mceText {font-family:Monospace}
.thebigreasonSkin .mceMenu .mceIcon {position:absolute; top:0; left:0; width:22px;}
.thebigreasonSkin .mceMenu .mceMenuItemEnabled a:hover, .thebigreasonSkin .mceMenu .mceMenuItemActive {background-color:#dbecf3}
.thebigreasonSkin td.mceMenuItemSeparator {background:#DDD; height:1px}
.thebigreasonSkin .mceMenuItemTitle a {border:0; background:#EEE; border-bottom:1px solid #DDD}
.thebigreasonSkin .mceMenuItemTitle span.mceText {color:#000; font-weight:bold; padding-left:4px}
.thebigreasonSkin .mceMenuItemDisabled .mceText {color:#888}
.thebigreasonSkin .mceMenuItemSelected .mceIcon {background:url('img/menu-check.png')}
.thebigreasonSkin .mceNoIcons .mceMenuItemSelected a {background:url('img/menu-arrow.png') no-repeat -6px center}
.thebigreasonSkin .mceMenu span.mceMenuLine {display:none}
.thebigreasonSkin .mceMenuItemSub a {background:url('img/menu-arrow.png') no-repeat top right;}

/* Progress,Resize */
.thebigreasonSkin .mceBlocker {position:absolute; left:0; top:0; z-index:1000; opacity:0.5; filter:alpha(opacity=50); background:#FFF}
.thebigreasonSkin .mceProgress {position:absolute; left:0; top:0; z-index:1001; background:url('img/progress.gif') no-repeat; width:32px; height:32px; margin:-16px 0 0 -16px}
.thebigreasonSkin .mcePlaceHolder {border:1px dotted gray}

/* Formats */
.thebigreasonSkin .mce_formatPreview a {font-size:10px}
.thebigreasonSkin .mce_p span.mceText {}
.thebigreasonSkin .mce_address span.mceText {font-style:italic}
.thebigreasonSkin .mce_pre span.mceText {font-family:monospace}
.thebigreasonSkin .mce_h1 span.mceText {font-weight:bolder; font-size: 2em}
.thebigreasonSkin .mce_h2 span.mceText {font-weight:bolder; font-size: 1.5em}
.thebigreasonSkin .mce_h3 span.mceText {font-weight:bolder; font-size: 1.17em}
.thebigreasonSkin .mce_h4 span.mceText {font-weight:bolder; font-size: 1em}
.thebigreasonSkin .mce_h5 span.mceText {font-weight:bolder; font-size: .83em}
.thebigreasonSkin .mce_h6 span.mceText {font-weight:bolder; font-size: .75em}

/* Theme */
.thebigreasonSkin span.mce_bold {background-position:0 0}
.thebigreasonSkin span.mce_italic {background-position:-60px 0}
.thebigreasonSkin span.mce_underline {background-position:-140px 0}
.thebigreasonSkin span.mce_strikethrough {background-position:-120px 0}
.thebigreasonSkin span.mce_undo {background-position:-160px 0}
.thebigreasonSkin span.mce_redo {background-position:-100px 0}
.thebigreasonSkin span.mce_cleanup {background-position:-40px 0}
.thebigreasonSkin span.mce_bullist {background-position:-20px 0}
.thebigreasonSkin span.mce_numlist {background-position:-80px 0}
.thebigreasonSkin span.mce_justifyleft {background-position:-460px 0}
.thebigreasonSkin span.mce_justifyright {background-position:-480px 0}
.thebigreasonSkin span.mce_justifycenter {background-position:-420px 0}
.thebigreasonSkin span.mce_justifyfull {background-position:-440px 0}
.thebigreasonSkin span.mce_anchor {background-position:-200px 0}
.thebigreasonSkin span.mce_indent {background-position:-400px 0}
.thebigreasonSkin span.mce_outdent {background-position:-540px 0}
.thebigreasonSkin span.mce_link {background-position:-500px 0}
.thebigreasonSkin span.mce_unlink {background-position:-640px 0}
.thebigreasonSkin span.mce_sub {background-position:-600px 0}
.thebigreasonSkin span.mce_sup {background-position:-620px 0}
.thebigreasonSkin span.mce_removeformat {background-position:-580px 0}
.thebigreasonSkin span.mce_newdocument {background-position:-520px 0}
.thebigreasonSkin span.mce_image {background-position:-380px 0}
.thebigreasonSkin span.mce_help {background-position:-340px 0}
.thebigreasonSkin span.mce_code {background-position:-260px 0}
.thebigreasonSkin span.mce_hr {background-position:-360px 0}
.thebigreasonSkin span.mce_visualaid {background-position:-660px 0}
.thebigreasonSkin span.mce_charmap {background-position:-240px 0}
.thebigreasonSkin span.mce_paste {background-position:-560px 0}
.thebigreasonSkin span.mce_copy {background-position:-700px 0}
.thebigreasonSkin span.mce_cut {background-position:-680px 0}
.thebigreasonSkin span.mce_blockquote {background-position:-220px 0}
.thebigreasonSkin .mce_forecolor span.mceAction {background-position:-720px 0}
.thebigreasonSkin .mce_backcolor span.mceAction {background-position:-760px 0}
.thebigreasonSkin span.mce_forecolorpicker {background-position:-720px 0}
.thebigreasonSkin span.mce_backcolorpicker {background-position:-760px 0}

/* Plugins */
.thebigreasonSkin span.mce_advhr {background-position:-0px -20px}
.thebigreasonSkin span.mce_ltr {background-position:-20px -20px}
.thebigreasonSkin span.mce_rtl {background-position:-40px -20px}
.thebigreasonSkin span.mce_emotions {background-position:-60px -20px}
.thebigreasonSkin span.mce_fullpage {background-position:-80px -20px}
.thebigreasonSkin span.mce_fullscreen {background-position:-100px -20px}
.thebigreasonSkin span.mce_iespell {background-position:-120px -20px}
.thebigreasonSkin span.mce_insertdate {background-position:-140px -20px}
.thebigreasonSkin span.mce_inserttime {background-position:-160px -20px}
.thebigreasonSkin span.mce_absolute {background-position:-180px -20px}
.thebigreasonSkin span.mce_backward {background-position:-200px -20px}
.thebigreasonSkin span.mce_forward {background-position:-220px -20px}
.thebigreasonSkin span.mce_insert_layer {background-position:-240px -20px}
.thebigreasonSkin span.mce_insertlayer {background-position:-260px -20px}
.thebigreasonSkin span.mce_movebackward {background-position:-280px -20px}
.thebigreasonSkin span.mce_moveforward {background-position:-300px -20px}
.thebigreasonSkin span.mce_media {background-position:-320px -20px}
.thebigreasonSkin span.mce_nonbreaking {background-position:-340px -20px}
.thebigreasonSkin span.mce_pastetext {background-position:-360px -20px}
.thebigreasonSkin span.mce_pasteword {background-position:-380px -20px}
.thebigreasonSkin span.mce_selectall {background-position:-400px -20px}
.thebigreasonSkin span.mce_preview {background-position:-420px -20px}
.thebigreasonSkin span.mce_print {background-position:-440px -20px}
.thebigreasonSkin span.mce_cancel {background-position:-460px -20px}
.thebigreasonSkin span.mce_save {background-position:-480px -20px}
.thebigreasonSkin span.mce_replace {background-position:-500px -20px}
.thebigreasonSkin span.mce_search {background-position:-520px -20px}
.thebigreasonSkin span.mce_styleprops {background-position:-560px -20px}
.thebigreasonSkin span.mce_table {background-position:-580px -20px}
.thebigreasonSkin span.mce_cell_props {background-position:-600px -20px}
.thebigreasonSkin span.mce_delete_table {background-position:-620px -20px}
.thebigreasonSkin span.mce_delete_col {background-position:-640px -20px}
.thebigreasonSkin span.mce_delete_row {background-position:-660px -20px}
.thebigreasonSkin span.mce_col_after {background-position:-680px -20px}
.thebigreasonSkin span.mce_col_before {background-position:-700px -20px}
.thebigreasonSkin span.mce_row_after {background-position:-720px -20px}
.thebigreasonSkin span.mce_row_before {background-position:-740px -20px}
.thebigreasonSkin span.mce_merge_cells {background-position:-760px -20px}
.thebigreasonSkin span.mce_table_props {background-position:-980px -20px}
.thebigreasonSkin span.mce_row_props {background-position:-780px -20px}
.thebigreasonSkin span.mce_split_cells {background-position:-800px -20px}
.thebigreasonSkin span.mce_template {background-position:-820px -20px}
.thebigreasonSkin span.mce_visualchars {background-position:-840px -20px}
.thebigreasonSkin span.mce_abbr {background-position:-860px -20px}
.thebigreasonSkin span.mce_acronym {background-position:-880px -20px}
.thebigreasonSkin span.mce_attribs {background-position:-900px -20px}
.thebigreasonSkin span.mce_cite {background-position:-920px -20px}
.thebigreasonSkin span.mce_del {background-position:-940px -20px}
.thebigreasonSkin span.mce_ins {background-position:-960px -20px}
.thebigreasonSkin span.mce_pagebreak {background-position:0 -40px}
.thebigreasonSkin .mce_spellchecker span.mceAction {background-position:-540px -20px}
