/*  Login Form
------------------------------------------------------------------------------------------------------ */
body.login {
    font-size: 12px;
    margin: 0;
    background: #fff url(/static/admin/img/bg.jpg) 50% 0 no-repeat;
    background-size: cover;
}
.login_h1 {
    margin: 6% auto 45px auto;
    text-align: center;
    color: #fff;
    font-size: 35px;
    font-weight: bold;
    text-shadow: 0 1px 1px #555;
}
.login_h1 sup {
    font-size: 18px;
    font-style: normal;
    position: absolute;
    margin-left: 10px;
    margin-top: -10px;
}
.login_window {
    padding: 5px 0;
    background: #fff;
    margin: 45px auto 0 auto;
    -webkit-box-shadow: 1px 1px 2px 0 rgba(0, 0, 0, .3);
    box-shadow: 1px 1px 2px 0 rgba(0, 0, 0, .3);
    width: 400px;
    border-bottom: none;
    position: relative;
}
.login_window .header {
    height: 50px;
    border-bottom: 1px solid #e2e2e2;
    position: relative;
}
.login_window .header .switch {
    left: 70px;
    height: 45px;
    position: absolute;
    bottom: 0;
    font-size: 16px;
}
.login_window .header .switch #switch_login {
    color: #222;
    display: inline-block;
    height: 45px;
    line-height: 45px;
    outline: none;
    margin-right: 90px;
    padding: 0 10px;
    border-bottom: 2px solid #444;
}
.login_window .header .switch #switch_forget {
    color: #999;
    display: inline-block;
    height: 45px;
    line-height: 45px;
    outline: none;
}
.login_window #errornote {
    width: 70%;
    margin: 15px auto 10px auto;
    border: 1px solid #eee;
    border-radius: 3px;
    line-height: 22px;
    font-size: 14px;
    padding: 6px 15px;
    text-align: left;
}
#login-form, #reset-form {
    margin-top: 20px !important;
}
.login .submit-row, .login #content-main {
    width: 100% !important;
}
#login-form .form-row, #reset-form .form-row {
    border: none;
    padding: 15px 0 15px 50px;
    height: 40px;
}
.login #content {
    margin: 0;
    overflow: hidden;
}
.login #content-main,
.login .submit-row {
    float: none;
    margin: 0 auto;
}
.login #content-main {
    margin-top: 10px !important;
    margin-bottom: 10px !important;
}
.login .form-row label {
    display: block;
    float: left;
    padding: 0 10px 0 5px;
    margin: 0;
    width: 60px !important;
    font-size: 17px !important;
    font-weight: normal !important;
    color: #222;
    height: 40px;
    line-height: 38px;
}
.login .form-row #id_username, .login .form-row #id_password {
    width: 210px;
    height: 38px;
    padding: 0 0 0 5px;
    margin: 0;
    line-height: 38px !important;
    border: 1px solid #D7D7D7;
    background: #fff;
    color: #444 !important;
    border-radius: 2px;
    font-size: 16px;
    ime-mode: disabled;
    font-weight: normal;
}
#login-form .submit-row, #reset-form .submit-row {
    height: 60px;
    padding-top: 8px;
}
#login-form .button_blue, #reset-form .button_blue {
    width: 200px;
    margin-left: 105px;
    display: inline-block;
    float: left;
    height: 41px !important;
    border-radius: 4px;
    background: #2795dc;
    border: none;
    cursor: pointer;
    border-bottom: 2px solid #0078b3;
    color: #fff;
    font-size: 16px;
    font-weight: normal;
    padding: 0 10px !important;
    outline: none;
    font-family: "Microsoft Yahei", Arial, Helvetica, sans-serif;
}
#login-form .button_blue:hover, #reset-form .button_blue:hover {
    background: #0081c1;
    border-bottom: 3px solid #006698;
    *border-bottom: none;
    color: #fff;
    text-decoration: none;
}
.login span.help {
    font-size: 10px;
    display: block;
}
.login .submit-row * {
    margin-right: -1px;
}
.jianyi {
    text-align: center;
    margin-top: 25px;
    color: #B3B8C4;
}